==> java-util-3.4.0-sources.jar: com/cedarsoftware/util/convert/UUIDConversions.java <==
package com.cedarsoftware.util.convert;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.UUID;

/**
 * @author John DeRegnaucourt (jdereg@gmail.com)
 *         <br>
 *         Copyright (c) Cedar Software LLC
 *         <br><br>
 *         Licensed under the Apache License, Version 2.0 (the "License");
 *         you may not use this file except in compliance with the License.
 *         You may obtain a copy of the License at
 *         <br><br>
 *         <a href="http://www.apache.org/licenses/LICENSE-2.0">License</a>
 *         <br><br>
 *         Unless required by applicable law or agreed to in writing, software
 *         distributed under the License is distributed on an "AS IS" BASIS,
 *         WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *         See the License for the specific language governing permissions and
 *         limitations under the License.
 */
final class UUIDConversions {

    private UUIDConversions() {
    }

    static BigDecimal toBigDecimal(Object from, Converter converter) {
        return new BigDecimal(toBigInteger(from, converter));
    }

    static BigInteger toBigInteger(Object from, Converter converter) {
        String hex = from.toString().replace("-", "");
        return new BigInteger(hex, 16);
    }

    static Map<String, Object> toMap(Object from, Converter converter) {
        UUID uuid = (UUID) from;
        Map<String, Object> target = new LinkedHashMap<>();
        target.put(MapConversions.UUID, uuid.toString());
        return target;
    }
}

==> java-util-4.0.0-sources.jar: com/cedarsoftware/util/convert/UUIDConversions.java <==
package com.cedarsoftware.util.convert;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.UUID;

/**
 * @author John DeRegnaucourt (jdereg@gmail.com)
 *         <br>
 *         Copyright (c) Cedar Software LLC
 *         <br><br>
 *         Licensed under the Apache License, Version 2.0 (the "License");
 *         you may not use this file except in compliance with the License.
 *         You may obtain a copy of the License at
 *         <br><br>
 *         <a href="http://www.apache.org/licenses/LICENSE-2.0">License</a>
 *         <br><br>
 *         Unless required by applicable law or agreed to in writing, software
 *         distributed under the License is distributed on an "AS IS" BASIS,
 *         WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *         See the License for the specific language governing permissions and
 *         limitations under the License.
 */
final class UUIDConversions {

    private UUIDConversions() {
    }

    static BigDecimal toBigDecimal(Object from, Converter converter) {
        return new BigDecimal(toBigInteger(from, converter));
    }

    static BigInteger toBigInteger(Object from, Converter converter) {
        String hex = from.toString().replace("-", "");
        return new BigInteger(hex, 16);
    }

    static Map<String, Object> toMap(Object from, Converter converter) {
        UUID uuid = (UUID) from;
        Map<String, Object> target = new LinkedHashMap<>();
        target.put(MapConversions.UUID, uuid.toString());
        return target;
    }

    static Boolean toBoolean(Object from, Converter converter) {
        UUID uuid = (UUID) from;
        // false if all zeros, true otherwise
        return uuid.getMostSignificantBits() != 0L || uuid.getLeastSignificantBits() != 0L;
    }
}
